#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
#
# Copyright (c) 2016-2024 Baptiste Daroussin <bapt@FreeBSD.org>
#

docbookpath="@DOCBOOK_XSL@"

err() {
	ec=$1
	shift
	echo $@ >&2
	exit $ec
}

set -e
usage() {
	echo "Usage: $0 [--stringparam=param] <format> <file>" >&2
	exit 1
}

output=""
xslt=$(command -v xsltproc)
r=1
for arg in "$@"; do
	if [ -n "$r" ]; then
		unset r
		set --
	fi
	case "$arg" in
		--stringparam) set -- "$@" -P ;;
		*) set -- "$@" "$arg" ;;
	esac
done

while getopts "o:P:" option; do
	case "$option" in
	'o')
		output="> ${OPTARG}"
		;;
	'P')
		xslargs="--stringparam ${OPTARG%=*} ${OPTARG#*=}"
		;;
	*)
		err 1 "Unsupported option ${option}"
		;;
	esac
done
shift $((OPTIND-1))

[ $# -ne 2 ] && usage

case $1 in
man)
	xslpath=${docbookpath}/manpages/docbook.xsl
	cmd="docbook2mdoc ${2}"
	if [ -n "${PREFER_DOCBOOK2MDOC}" ]; then
		if [ -z "${output}" ]; then
			manvolnum=$(docbook2mdoc ${2} | awk '/^.Dt/ { print $NF }')
			output="> $(basename ${2%.*}.${manvolnum})"
		fi
	fi
	;;
html-nochunks)
	xslpath=${docbookpath}/html/docbook.xsl
	xslargs="${xslargs} -o $(basename ${2%.*}.html)"
	;;
html|html-dir)
	xslpath=${docbookpath}/html/chunk.xsl
	;;
txt)
	xslpath=${docbookpath}/html/docbook.xsl
	post_args="| sed -e 's/&#8212;/-/g' | html2text -nobs -o $(basename ${2%.*}.txt)"
	cmd="docbook2mdoc ${2} | mandoc -T utf8 > $(basename ${2%.*}.txt)"
	;;
*)
	err 1 "Unsupported format"
	;;
esac

if [ -n "${PREFER_DOCBOOK2MDOC}" -a -n "${cmd}" ]; then
	eval ${cmd} ${output}
else
	eval ${xslt} ${xslargs} ${xslpath} ${2} ${post_args} ${output}
fi
